@@ -20,7 +20,13 @@ Astro::Coord::ECI::Sun - Compute the position of the Sun.
      geodetic ($lat, $long, $alt);
  my ($time, $rise) = $sta->next_elevation ($sun);
  print "Sun @{[$rise ? 'rise' : 'set']} is ",
-     scalar localtime $time, "\n";
+     scalar gmtime $time, " UT\n";
+
+Although this example computes the Sun rise or set in Washington D.C.
+USA, the time is displayed in Universal Time. This is because I did not
+want to complicate the example by adding machinery to convert the time
+to the correct zone for Washington D.C. (which is UT - 5 except when
+Summer Time is in effect, when it is UT - 4).
 
 =head1 DESCRIPTION
 
@@ -44,13 +50,12 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.029_01';
+our $VERSION = '0.033_01';
 
 use base qw{Astro::Coord::ECI};
 
 use Astro::Coord::ECI::Utils qw{:all};
 use Carp;
-use Params::Util 0.25 qw{_CLASSISA};
 use POSIX qw{floor strftime};
 
 my %static = (
@@ -92,7 +97,7 @@ otherwise.
 sub new {
     my ($class, @args) = @_;
     ref $class and $class = ref $class;
-    if ($Singleton && $weaken && _CLASSISA($class, __PACKAGE__)) {
+    if ( $Singleton && $weaken && _classisa( $class, __PACKAGE__ ) ) {
 	if ($object) {
 	    $object->set (@args) if @args;
 	    return $object;
@@ -525,3 +530,5 @@ without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
 =cut
+
+# ex: set textwidth=72 :
