@@ -41,6 +41,9 @@ C<timelocal> into your name space.
 
 =back
 
+Under Perl 5.6 you may find that, if you use any of the above tags, you
+need to specify them first in your import list.
+
 =head2 The following constants are exportable:
 
  AU = number of kilometers in an astronomical unit
@@ -91,13 +94,14 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.029_01';
+our $VERSION = '0.033_01';
 our @ISA = qw{Exporter};
 
 use Carp;
 ## use Config;
 use Data::Dumper;
 use POSIX qw{floor strftime};
+use Scalar::Util qw{ blessed };
 
 my @time_routines;
 
@@ -132,11 +136,13 @@ our @EXPORT_OK = ( qw{
 	jd2datetime jday2000 julianday load_module looks_like_number max
 	min mod2pi nutation_in_longitude nutation_in_obliquity obliquity
 	omega rad2deg tan theta0 thetag vector_cross_product
-	vector_dot_product vector_magnitude vector_unitize },
+	vector_dot_product vector_magnitude vector_unitize
+       	_classisa _instance },
 	@time_routines );
 
 our %EXPORT_TAGS = (
     all => \@EXPORT_OK,
+    params => [ qw{ _classisa _instance } ],
     time => \@time_routines,
 );
 
@@ -977,6 +983,32 @@ sub vector_unitize {
     return [ map { $_ / $mag } @{ $b } ];
 }
 
+#	_classisa( 'Foo', 'Bar' );
+#
+#	Returns true if Foo->isa( 'Bar' ) is true, and false otherwise.
+#	In particular, returns false if the first argument is a
+#	reference.
+
+sub _classisa {
+    my ( $invocant, $class ) = @_;
+    ref $invocant and return;
+    defined $invocant or return;
+    return $invocant->isa( $class );
+}
+
+#	_instance( $foo, 'Bar' );
+#
+#	Returns true if $foo is an instance of 'Bar', and false
+#	otherwise. In particular, returns false if $foo is not a
+#	reference, or if it is not blessed.
+
+sub _instance {
+    my ( $object, $class ) = @_;
+    ref $object or return;
+    blessed( $object ) or return;
+    return $object->isa( $class );
+}
+
 #	$epoch_time = _parse_time_iso_8601
 #
 #	Parse ISO 8601 date/time. I do not intend to expose this, since
